package com.example;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.io.PrintWriter;
import java.net.Socket;

import org.json.JSONObject;

public class ClientHandler implements Runnable {

    private final Socket socket;

    public ClientHandler(Socket socket) {
        this.socket = socket;
    }

    @Override
    public void run() {
        BufferedReader in = null;
        PrintWriter out = null;

        try {
            in = new BufferedReader(new InputStreamReader(socket.getInputStream()));
            out = new PrintWriter(socket.getOutputStream(), true);

            System.out.println("Client connected: " + socket.getInetAddress());

            String rawMessage;
            while ((rawMessage = in.readLine()) != null) {
                System.out.println("📨 Received: " + rawMessage);

                String response = handleEvent(rawMessage);
                System.out.println("📤 Responding: " + response);
                out.println(response);
            }

            System.out.println("Client disconnected: " + socket.getInetAddress());

        } catch (IOException e) {
            System.err.println("Client handler error: " + e.getMessage());
        } finally {
            try {
                if (in != null) in.close();
                if (out != null) out.close();
                socket.close();
            } catch (IOException e) {
                System.err.println("Error closing client socket: " + e.getMessage());
            }
        }
    }

    private String handleEvent(String rawMessage) {
        try {
            JSONObject message = new JSONObject(rawMessage);

            String pattern = message.optString("pattern", "unknown");
            JSONObject data = message.optJSONObject("data");

            // You could use pattern to route logic
            String resultMessage = "Received pattern: " + pattern + ", data: " + (data != null ? data.toString() : "null");

            // Build response
            JSONObject response = new JSONObject();
            response.put("pattern", pattern);
            response.put("result", resultMessage);

            return response.toString();

        } catch (Exception e) {
            JSONObject error = new JSONObject();
            error.put("error", "Invalid message format: " + e.getMessage());
            return error.toString();
        }
    }
}